pub struct BrowseHandle { /* private fields */ }Expand description
Handle for receiving events from a single browse operation.
Implementations
Sourceimpl BrowseHandle
impl BrowseHandle
Sourcepub fn new(rx: Receiver<BrowserEvent>) -> Self
pub fn new(rx: Receiver<BrowserEvent>) -> Self
Create a new handle from an mpsc receiver.
Sourcepub async fn recv(&mut self) -> Option<BrowserEvent>
pub async fn recv(&mut self) -> Option<BrowserEvent>
Receive the next event, or None if the browse stopped.