Module types

Module types 

Structs

ServiceRecord
A service instance as seen on the network. Used in browse results, resolve results, register confirmations, and event payloads. This is THE service representation across all domains.
ServiceType
Validated DNS-SD service type.
SessionId
Unique identifier for a connection/session.

Enums

EventKind
Service event kinds for subscribe streams.
ServiceTypeError
Error parsing a DNS-SD service type string.

Constants

META_QUERY
DNS-SD meta-query type for discovering all service types on the network.