Module types
koi_
common
0.2.202603241449
Module types
Module Items
Structs
Enums
Constants
In crate koi_
common
koi_common
Module
types
Structs

Service
Record
A service instance as seen on the network. Used in browse results, resolve results, register confirmations, and event payloads. This is THE service representation across all domains.
Service
Type
Validated DNS-SD service type.
Session
Id
Unique identifier for a connection/session.
Enums

Event
Kind
Service event kinds for subscribe streams.
Service
Type
Error
Error parsing a DNS-SD service type string.
Constants

META_
QUERY
DNS-SD meta-query type for discovering all service types on the network.